spannertools.BracketSpanner
===========================

.. inheritance-diagram:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner
   :private-bases:

.. autoclass:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.components

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.duration_in_seconds

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.leaves

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.override

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.preprolated_duration

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.prolated_duration

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.set

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.start_offset

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.stop_offset

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.written_duration

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

Methods
-------

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.append

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.append_left

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.clear

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.extend

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.extend_left

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.fracture

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.fuse

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.index

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.pop

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.pop_left

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

Special Methods
---------------

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__call__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__contains__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__getitem__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__len__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__lt__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__repr__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`
